use v5.14;

package Local::Glossary;
use strict;
use base 'Local::DocBook';

use warnings;
no warnings;

use subs qw();
use vars qw($VERSION);

use Carp;

$VERSION = '0.10';

sub DEBUG () { 0 }

sub document_header
	{
	my $string = <<"XML";
<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE glossary PUBLIC "-//OASIS//DTD DocBook XML V4.4//EN"
	"http://www.oasis-open.org/docbook/xml/4.4/docbookx.dtd">
<!-- created by brian's private converter -->
XML

	my $id = join '-', $_[0]->title, 'glossary';

	$string .= <<"XML";
<glossary id="$id">

XML
	}

=item document_footer

=cut

sub document_footer
	{
	my $string .= <<"XML";
</glossdef></glossentry></glossary>
XML
	}

sub start_item_bullet
	{
	my( $self ) = @_;
	$self->{saw_term} = 0;

	$self->add_xml_tag( "</glossdef></glossentry>\n\n" )
		unless $self->is_first_list_level_item;
	$self->add_list_level_item;
	$self->add_xml_tag( "<glossentry>\n" );
	$self->start_Para;
	}

sub end_item_bullet
	{
	my $self = shift;
	$self->end_Para;
	$self->{in_item} = 0;
	$self->{items}++;
	}

sub start_over_bullet { 	
	$_[0]->start_list_level;
	$_[0]->{in_list}++;
	}

sub end_over_bullet {}

	
sub start_Para {
	my $self = shift;

	return if $self->{in_figure};

	my $tag = do {
		if( ! $self->{in_list} ) {
			'<para>';
			}
		else {
			my $tag = $self->{saw_term} == 0 ? '<glossterm>' : '<para>';
			$self->{saw_term}++;
			$tag;
			}
		};
				
	$self->add_xml_tag( $tag );

	$self->escape_and_emit;

	$self->{'in_para'} = 1;
	}

sub end_Para {
	my $self = shift;

	return if $self->{in_figure};

	my $tag = do {
		if( ! $self->{in_list} ) {
			'</para>';
			}
		else {
			my $tag = $self->{saw_term} == 1 ? '</glossterm><glossdef>' : '</para>';
			$self->{saw_term}++;
			$tag;
			}
		};

	$self->add_xml_tag( "$tag\n\n" );

	$self->end_non_code_text;

	$self->{'in_para'} = 0;
	}
	
1;

__END__

<!DOCTYPE glossary PUBLIC "-//OASIS//DTD DocBook XML V4.1.2//EN"
          "http://www.oasis-open.org/docbook/xml/4.1.2/docbookx.dtd">
<glossary><title>Example Glossary</title>
<para>
This is not a real glossary, it's just an example.
</para>

<!-- ... -->

<glossdiv><title>E</title>

<glossentry id="xml"><glossterm>Extensible Markup Language</glossterm>
  <acronym>XML</acronym>
<glossdef>
  <para>Some reasonable definition here.</para>
  <glossseealso otherterm="sgml">SGML</glossseealso>
</glossdef>
</glossentry>

</glossdiv>

<!-- ... -->

<glossdiv><title>S</title>

<glossentry><glossterm>SGML</glossterm>
<glosssee otherterm="sgml"/>
</glossentry>

<glossentry id="sgml"><glossterm>Standard Generalized
  Markup Language</glossterm><acronym>SGML</acronym>
  <abbrev>ISO 8879:1986</abbrev>
<glossdef>
  <para>Some reasonable definition here.</para>
  <glossseealso otherterm="xml">XML</glossseealso>
</glossdef>
</glossentry>

</glossdiv>
</glossary>


